
.. include:: ../README.rst

Be sure to check out the :ref:`about_docs` page for a guide on how to get the most of
the documentation!

.. toctree::
   :maxdepth: 2

   using/index
   extending/index
   contributing/index
   maths/index
   api/index
   glossary
   changes
   about




